<?php
  /**************************************************************************\
  * phpGroupWare                                                             *
  * http://www.phpgroupware.org                                              *
  * Written by Mark Peters <skeeter@phpgroupware.org>                        *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/
	/* $Id: hook_deleteaccount.inc.php,v 1.2.4.1 2005/12/04 04:45:02 skwashd Exp $ */
	
	// Delete all records for a user
	$table_locks = Array('phpgw_todo');
	$db2 = $GLOBALS['phpgw']->db;
	$db2->lock($table_locks);

	if(intval($_POST['new_owner']) == 0)
	{
		$db2->query('DELETE FROM phpgw_todo WHERE todo_owner = ' . intval($_POST['account_id']),__LINE__,__FILE__);
	}
	else
	{
		$db2->query('UPDATE phpgw_todo SET todo_owner = '.intval($_POST['new_owner'])
			. ' WHERE todo_owner = ' . intval($_POST['account_id']),__LINE__,__FILE__);
	}
	$db2->unlock();
?>
